import ftcomputing.roboTX.*;
/**
 * Einfhrung in die Programmierung der Industry Robot 
 * mit ftcomputing.roboTX.jar : FishFaceTX am ROBO TX Controller
 * 
 * Sulenrobot nach Industry Robot II mit der dort angegebenen Interface-Belegung
 * Sule M1, Endtaster I1, Impulstaster C1, 
 * Arm waagerecht M2, I2, C2, Arm senkrecht M3, I3, C3
 * Greifer M4, I4, C4, alternative Lampe
 * Die Robotkomponenten mssen bei Linkslauf auf den zugehrenden Endtaster drehen.
 * 
 * Der ROBO TX Controller ist mit openController("COM4") verbunden, ggf. ndern
 * 
 * @author Ulrich Mller 
 * @version 16.03.10
 */
public class RobTXzwei {
    private FishFaceTX tx;
    private int[] actPos = new int[4];
    static final int FullSpeed = 512;

    public RobTXzwei() {
        tx = new FishFaceTX();
    }

    public void start() {
        tx.openController("COM4");
    }
    public void ende() {
        tx.closeController();
    }
    /**
     * Fahren auf Home-Position
     */
    public void driveHome(Mot motNr) {
        System.out.println("Motor " + motNr + " -> Home");
        tx.setMotor(motNr, Dir.Left);
        tx.waitForInput(Unv.values()[motNr.ordinal()], true);
        tx.setMotor(motNr, Dir.Off);
        actPos[motNr.ordinal()] = 0;
        System.out.println(motNr + "--- Zu Hause ---");
    }
    
    /**
     * Simultanes Anfahren der Home-Position des ganzen Roboters
     */
    public void moveHome() {
        System.out.println("Es geht nach Hause");
        for(int i = 0; i < 3; i++) 
            tx.startRobMotor(Mot.values()[i], Dir.Left, FullSpeed, 9999);
        tx.waitForMotors(Mot.M1, Mot.M2, Mot.M3);
        for(int i = 0; i < 3; i++) actPos[i] = 0;
        System.out.println("--- wir sind zu Hause ---");
    }
    
    /**
     * Fahren auf vorgegebene Position
     */
    public void driveTo(Mot motNr, int pos) {
        System.out.println("Motor " + motNr + " fhrt auf Position : " + pos);
        if (pos < actPos[motNr.ordinal()]) 
            tx.startRobMotor(motNr, Dir.Left, FullSpeed, actPos[motNr.ordinal()] - pos);
        else if (pos > actPos[motNr.ordinal()]) 
            tx.startRobMotor(motNr, Dir.Right, FullSpeed, pos - actPos[motNr.ordinal()]);
        tx.waitForMotors(motNr);
        actPos[motNr.ordinal()] = pos;
        System.out.println("Auf Position : " + pos);
    }
    
    /**
     * Simultanes Anfahren einer vorgegebenen Position
     */
    public void moveTo(int... pos) {
       System.out.println("Robot fhrt auf neue Position");
       for(int i = 0; i < pos.length; i++) {
           if(pos[i] < actPos[i]) 
               tx.startRobMotor(Mot.values()[i], Dir.Left, FullSpeed, actPos[i] - pos[i]);
           else if(pos[i] > actPos[i]) 
               tx.startRobMotor(Mot.values()[i], Dir.Right, FullSpeed, pos[i] - actPos[i]);
        }
        tx.waitForMotors(Mot.M1, Mot.M2, Mot.M3);
        for(int i = 0; i < pos.length; i++) actPos[i] = pos[i];
        System.out.println("--- Mir san doa ---");
    }
}
