package RobTXtest;
import ftcomputing.roboTX.*;
/**
 * Industry Robots II : Sulenroboter betrieben ber den Robo TX Controller
 * 
 * @author Ulrich Mller 
 * @version 17.03.10

 */
public class RobTXir2 {
    private FishFaceTX tx;
    private int[] actPos = new int[3];
    private int gripOpen;
    
    static final int FullSpeed = 512;
    static final int GripClosed = 10;
    static final Mot[] RobMot = new Mot[]{Mot.M1, Mot.M2, Mot.M3};
    static final Mot GripMot = Mot.M4;
    
    public RobTXir2() {
        tx = new FishFaceTX();
    }
    public void start() {
        tx.openController("COM4");
        for(int pos = 0; pos < actPos.length; pos++ ) actPos[pos] = 0;
        gripOpen = 0;
    }
    public void ende() {
        tx.closeController();
    }
    
    /**
     * Simultanes Anfahren der Home-Position des ganzen Roboters
     */
    public void moveHome() {
        System.out.println("Home simultan");
        for(Mot mot : RobMot) 
            tx.startRobMotor(mot, Dir.Left, FullSpeed, 9999);
        tx.waitForMotors(RobMot);
        gripper(0);
        for(int pos = 0; pos < actPos.length; pos++ ) actPos[pos] = 0;
    }
        
    /**
     * Simultanes Anfahren einer vorgegebenen Position
     */
    public void moveTo(int... pos) {
       System.out.println("Robot fhrt auf neue Position");
       for(int p : pos) System.out.print(" - " + p);
       for(int i = 0; i < actPos.length; i++) {
           if(pos[i] < actPos[i]) 
               tx.startRobMotor(Mot.values()[i], Dir.Left, FullSpeed, 
            		   actPos[i] - pos[i]);
           else if(pos[i] > actPos[i]) 
               tx.startRobMotor(Mot.values()[i], Dir.Right, FullSpeed, 
            		   pos[i] - actPos[i]);
        }
        tx.waitForMotors(Mot.M1, Mot.M2, Mot.M3);
        for(int i = 0; i < actPos.length; i++) actPos[i] = pos[i];
    }
    
    /**
     * Bettigen Greifer
     */
    public void gripper(int open) {
        if(open == 0) { 
          System.out.println(" : Greifer ffnet");
          tx.startRobMotor(GripMot, Dir.Left, FullSpeed, 9999);
          tx.waitForMotors(GripMot);
          gripOpen = 0;
        }
        else if (gripOpen == 0) { 
          System.out.println(" : Greifer schliet");
          tx.startRobMotor(GripMot, Dir.Right, FullSpeed, GripClosed);
          tx.waitForMotors(GripMot);
          gripOpen = GripClosed;
        }
    }

}
