package eduLine;

public class CrossRoads extends eduJava {
	private final int jeError        = 0xE0000001;
	private final int jePollInterval = 12;
	private final int notOpen        = 999;

	private int     iHandle      = notOpen;
	private boolean notHalt      = true;

	public class DeviceData{
		public String Name;
		public int    Type;
		public int    SerialNr;
		public String Firmware;
	}

	public CrossRoads() {
		super();
	}
	public DeviceData getActDevice(){
		if (iHandle == notOpen)
			throw (new CrossRoadsException("KeinOpen.getActDevice"));
		DeviceData dd = new DeviceData();
		dd.Name       = "EDU_LINE";
		dd.Type       = jeGetActDeviceType(iHandle);
		dd.SerialNr   = jeGetActDeviceSerialNr(iHandle);
		int f         = jeGetActDeviceFirmwareNr(iHandle);
		dd.Firmware   = String.format("%d.%d.%d.%d", 
				                     (f & 0xFF000000) >> 24,
				                     (f & 0xFF0000) >> 16,
				                     (f & 0xFF00) >> 8,
				                     (f & 0xFF)); 
		return dd;
	}
    public void clearOutputs() {
		if (iHandle == notOpen)
			throw (new CrossRoadsException("KeinOpen.clearOutputs"));
		int res = jeSetOutputs(iHandle, 0);
		if (res == jeError)
			throw (new CrossRoadsException("DeviceProblem.clearOutputs"));
	}
	public void closeUSB() {
		if (iHandle == notOpen) 
			throw (new CrossRoadsException("DeviceProblem.closeUSB"));
		iHandle = notOpen;
	}
	public boolean finish() {
		Thread.yield();
		if (iHandle == notOpen)
			throw (new CrossRoadsException("KeinOpen.finish"));
		if (notHalt || escape() != 0)
			return true;
		if (jeGetInputs(iHandle) == jeError)
			throw (new CrossRoadsException("DeviceProblem.finish"));
		return false;
	}
	public boolean getInput(Inp inputNr) {
		if (iHandle == notOpen)
			throw (new CrossRoadsException("KeinOpen.getInput"));
		int res = jeGetInput(iHandle, inputNr.ordinal());
		if (res == jeError)
			throw (new CrossRoadsException("DeviceProblem.getInput"));
		return (res == 1) ? true : false;
	}
	public int getInputs() {
		if (iHandle == notOpen)
			throw (new CrossRoadsException("KeinOpen.getInputs"));
		int res = jeGetInputs(iHandle);
		if (res == jeError)
			throw (new CrossRoadsException("DeviceProblem.getInputs"));
		return res;
	}
	public int getVoltage() {
		if (iHandle == notOpen)
			throw (new CrossRoadsException("KeinOpen.getVoltage"));
		int res = jeGetVoltage(iHandle, 1);
		if (res == jeError)
			throw (new CrossRoadsException("DeviceProblem.getVoltage"));
		return res;
	}
	public boolean getNotHalt() {
		return notHalt;
	}
	public void  setNotHalt(boolean OnOff) {
		notHalt = OnOff;
	}
	public void openUSB() {
		openUSB(0, 0);
	}
	public void openUSB(int ifTyp, int serialNr) {
		iHandle = jeOpenUSB(ifTyp, serialNr);
		if (iHandle == jeError)
			throw new CrossRoadsException("DeviceProblem.openUSB");
		jeSetOutputs(iHandle, 0);
		notHalt       = false;
	}
	public boolean getOpenStatus() {
		return iHandle == notOpen ? false : true;
	}
	public int getOutputs() {
		if (iHandle == notOpen)
			throw (new CrossRoadsException("KeinOpen.getOutputs"));
		int res = jeGetOutputs(iHandle);
		if (res == jeError)
			throw (new CrossRoadsException("DeviceProblem.getOutputs"));
		return res;
	}
	public void pause(int mSek) {
		if (iHandle == notOpen)
			throw (new CrossRoadsException("KeinOpen.Pause"));
		int sZeit = getTickCount();
		do {
			Thread.yield();
			if (notHalt || escape() != 0)
				return;
			if (jeGetInputs(iHandle) == jeError)
				throw (new CrossRoadsException("DeviceProblem.pause"));
			try{Thread.sleep(jePollInterval);}catch(InterruptedException ei){}
		} while (getTickCount() - sZeit < mSek);		
	}
	public void setOutput(Out outputNr, Dir onOff) {
		if (iHandle == notOpen)
			throw (new CrossRoadsException("KeinOpen.setOutput"));
		if (jeSetOutput(iHandle, outputNr.ordinal(), onOff.ordinal()) == jeError)
			throw (new CrossRoadsException("DeviceProblem.setOutput"));
	}
	public void setOutputs(int status) {
		if (iHandle == notOpen)
			throw (new CrossRoadsException("KeinOpen.setOutputss"));
		if (jeSetOutputs(iHandle, status) == jeError)
			throw (new CrossRoadsException("DeviceProblem.setOutputs"));
		
	}
	public void waitForInput(Inp inputNr) {
		waitForInput(inputNr, true);
	}
	public void waitForInput(Inp inputNr, boolean onOff) {
		if (iHandle == notOpen)
			throw (new CrossRoadsException("KeinOpen.waitForInput"));
		do {
			if (notHalt || escape() != 0)
				return;
			if (jeGetInputs(iHandle) == jeError)
				throw (new CrossRoadsException("DeviceProblem.waitForInput"));
			try{Thread.sleep(jePollInterval);}catch(InterruptedException ei){}
		} while (!getInput(inputNr) == onOff);		
	}
	public static String Version() {
		return "2.09.00.01";
	}
	public void waitForLow(Inp inputNr) {
		waitForInput(inputNr, true);
		waitForInput(inputNr, false);		
	}
	public void waitForHigh(Inp inputNr) {
		waitForInput(inputNr, false);
		waitForInput(inputNr, true);
	}
}
